@@ -4,7 +4,7 @@ use warnings;
 
 package Error::Hierarchy;
 BEGIN {
-  $Error::Hierarchy::VERSION = '1.102500';
+  $Error::Hierarchy::VERSION = '1.102720';
 }
 # ABSTRACT: Support for hierarchical exception classes
 use Carp;
@@ -92,7 +92,7 @@ Error::Hierarchy - Support for hierarchical exception classes
 
 =head1 VERSION
 
-version 1.102500
+version 1.102720
 
 =head1 SYNOPSIS
 
@@ -227,7 +227,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
