@@ -4,7 +4,7 @@ use warnings;
 
 package Error::Hierarchy::Internal;
 BEGIN {
-  $Error::Hierarchy::Internal::VERSION = '1.102500';
+  $Error::Hierarchy::Internal::VERSION = '1.102720';
 }
 # ABSTRACT: Base class for internal exceptions
 
@@ -31,7 +31,7 @@ Error::Hierarchy::Internal - Base class for internal exceptions
 
 =head1 VERSION
 
-version 1.102500
+version 1.102720
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
