@@ -4,7 +4,7 @@ use warnings;
 
 package Error::Hierarchy::Internal::DBI::STH;
 BEGIN {
-  $Error::Hierarchy::Internal::DBI::STH::VERSION = '1.102500';
+  $Error::Hierarchy::Internal::DBI::STH::VERSION = '1.102720';
 }
 # ABSTRACT: DBI statement-related exception
 use Error::Hierarchy::Util 'load_class';
@@ -85,7 +85,7 @@ Error::Hierarchy::Internal::DBI::STH - DBI statement-related exception
 
 =head1 VERSION
 
-version 1.102500
+version 1.102720
 
 =head1 DESCRIPTION
 
@@ -149,7 +149,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
