@@ -4,7 +4,7 @@ use warnings;
 
 package Error::Hierarchy::Mixin;
 BEGIN {
-  $Error::Hierarchy::Mixin::VERSION = '1.102500';
+  $Error::Hierarchy::Mixin::VERSION = '1.102720';
 }
 # ABSTRACT: Provides often-used exception-related methods
 use Error;    # to get $Error::Depth
@@ -67,7 +67,7 @@ Error::Hierarchy::Mixin - Provides often-used exception-related methods
 
 =head1 VERSION
 
-version 1.102500
+version 1.102720
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
