@@ -4,7 +4,7 @@ use warnings;
 
 package Error::Hierarchy::Test;
 BEGIN {
-  $Error::Hierarchy::Test::VERSION = '1.102500';
+  $Error::Hierarchy::Test::VERSION = '1.102720';
 }
 # ABSTRACT: Tools to test hierarchical exceptions
 use Test::Builder;
@@ -67,7 +67,7 @@ Error::Hierarchy::Test - Tools to test hierarchical exceptions
 
 =head1 VERSION
 
-version 1.102500
+version 1.102720
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
